summaryrefslogtreecommitdiff
path: root/maintenance/rebuildLocalisationCache.php
diff options
context:
space:
mode:
authorPierre Schmitz <pierre@archlinux.de>2014-12-27 15:41:37 +0100
committerPierre Schmitz <pierre@archlinux.de>2014-12-31 11:43:28 +0100
commitc1f9b1f7b1b77776192048005dcc66dcf3df2bfb (patch)
tree2b38796e738dd74cb42ecd9bfd151803108386bc /maintenance/rebuildLocalisationCache.php
parentb88ab0086858470dd1f644e64cb4e4f62bb2be9b (diff)
Update to MediaWiki 1.24.1
Diffstat (limited to 'maintenance/rebuildLocalisationCache.php')
-rw-r--r--maintenance/rebuildLocalisationCache.php10
1 files changed, 6 insertions, 4 deletions
diff --git a/maintenance/rebuildLocalisationCache.php b/maintenance/rebuildLocalisationCache.php
index b7f306b1..b04639c0 100644
--- a/maintenance/rebuildLocalisationCache.php
+++ b/maintenance/rebuildLocalisationCache.php
@@ -52,6 +52,7 @@ class RebuildLocalisationCache extends Maintenance {
if ( $this->hasOption( 'memory-limit' ) ) {
return parent::memoryLimit();
}
+
return '1000M';
}
@@ -90,7 +91,7 @@ class RebuildLocalisationCache extends Maintenance {
if ( $this->hasOption( 'outdir' ) ) {
$conf['storeDirectory'] = $this->getOption( 'outdir' );
}
- $lc = new LocalisationCache_BulkLoad( $conf );
+ $lc = new LocalisationCacheBulkLoad( $conf );
$allCodes = array_keys( Language::fetchLanguageNames( null, 'mwfile' ) );
if ( $this->hasOption( 'lang' ) ) {
@@ -148,9 +149,9 @@ class RebuildLocalisationCache extends Maintenance {
/**
* Helper function to rebuild list of languages codes. Prints the code
* for each language which is rebuilt.
* @param $codes array List of language codes to rebuild.
* @param $lc LocalisationCache Instance of LocalisationCache_BulkLoad (?)
* @param $force bool Rebuild up-to-date languages
* @return int Number of rebuilt languages
*/
private function doRebuild( $codes, $lc, $force ) {
@@ -162,6 +163,7 @@ class RebuildLocalisationCache extends Maintenance {
$numRebuilt++;
}
}
+
return $numRebuilt;
}
@@ -148,9 +149,9 @@ class RebuildLocalisationCache extends Maintenance {
* Helper function to rebuild list of languages codes. Prints the code
* for each language which is rebuilt.
- * @param $codes array List of language codes to rebuild.
- * @param $lc LocalisationCache Instance of LocalisationCache_BulkLoad (?)
- * @param $force bool Rebuild up-to-date languages
+ * @param array $codes List of language codes to rebuild.
+ * @param LocalisationCache $lc Instance of LocalisationCacheBulkLoad (?)
+ * @param bool $force Rebuild up-to-date languages
* @return int Number of rebuilt languages
*/